fn decompose_left_to_right_equations(
predicate: &MirScalarExpr,
lhs_cutoff: usize,
) -> Option<(Vec<(usize, usize)>, Vec<(usize, usize)>)>Expand description
If predicate can be decomposed as any number of col(x) = col(y) expressions anded together, return them.
In order to only find useful equations, one column must be < lhs_cutoff and one must be >= lhs_cutoff.